#
# spec file for package keepassxc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           keepassxc
Version:        2.2.0
Release:        4.1
Summary:        Qt5-based Password Manager
License:        GPL-2.0 OR GPL-3.0
Group:          Productivity/Security
Url:            https://www.keepassxc.org/
Source0:        https://github.com/keepassxreboot/keepassxc/releases/download/%{version}/keepassxc-%{version}-src.tar.xz
Source1:        https://github.com/keepassxreboot/keepassxc/releases/download/%{version}/keepassxc-%{version}-src.tar.xz.sig
Source2:        https://keepassxc.org/keepassxc_master_signing_key.asc#/%{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libgcrypt-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libykpers-devel
BuildRequires:  libyubikey-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)
Requires:       hicolor-icon-theme
Requires(post): hicolor-icon-theme
Requires(post): shared-mime-info
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): shared-mime-info
Requires(postun): update-desktop-files
Recommends:     %{name}-lang

%description
A password manager or safe which manages your passwords. Databases
are locked with a master key/password or a key disk. The databases
are encrypted using AES and Twofish.

%lang_package

%prep
%setup -q

%build
%cmake \
  -DWITH_XC_AUTOTYPE=ON \
  -DWITH_XC_YUBIKEY=ON \
  -DWITH_XC_HTTP=ON
make %{?_smp_mflags}

%install
%cmake_install
%suse_update_desktop_file %{name} X-SuSE-DesktopUtility
%fdupes -s %{buildroot}/%{_prefix}

%check
# gh#keepassxreboot/keepassxc#667
export LANG=en_US.UTF-8
%ctest

%post
%mime_database_post
%desktop_database_post
%icon_theme_cache_post

%postun
%mime_database_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING LICENSE*
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/wordlists/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor
%{_datadir}/mime/packages/%{name}.xml
%dir %{_libdir}/%{name}
%{_libdir}/keepassxc/libkeepassx-autotype-xcb.so

%files lang
%defattr(-,root,root)
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations

%changelog
* Mon Jun 26 2017 mpluskal@suse.com
- Update to version 2.2.0:
  * Added YubiKey 2FA integration for unlocking databases [#127]
  * Added TOTP support [#519]
  * Added CSV import tool [#146, #490]
  * Added KeePassXC CLI tool [#254]
  * Added diceware password generator [#373]
  * Added support for entry references [#370, #378]
  * Added support for Twofish encryption [#167]
  * Enabled DEP and ASLR for in-memory protection [#371]
  * Enabled single instance mode [#510]
  * Enabled portable mode [#645]
  * Enabled database lock on screensaver and session lock [#545]
  * Redesigned welcome screen with common features and recent databases [#292]
  * Multiple updates to search behavior [#168, #213, #374, #471, #603, #654]
  * Added auto-type fields {CLEARFIELD}, {SPACE}, {{}, {}} [#267, #427, #480]
  * Fixed auto-type errors on Linux [#550]
  * Prompt user prior to executing a cmd:// URL [#235]
  * Entry attributes can be protected (hidden) [#220]
  * Added extended ascii to password generator [#538]
  * Added new database icon to toolbar [#289]
  * Added context menu entry to empty recycle bin in databases [#520]
  * Added "apply" button to entry and group edit windows [#624]
  * Added macOS tray icon and enabled minimize on close [#583]
  * Fixed issues with unclean shutdowns [#170, #580]
  * Changed keyboard shortcut to create new database to CTRL+SHIFT+N [#515]
  * Compare window title to entry URLs [#556]
  * Implemented inline error messages [#162]
  * Ignore group expansion and other minor changes when making database "dirty" [#464]
  * Updated license and copyright information on souce files [#632]
  * Added contributors list to about dialog [#629]
- Drop no longer needed keepassxc-qt5.9.patch
- Enforce locale setting for tests (gh#keepassxreboot/keepassxc#667)
* Wed Jun 21 2017 mpluskal@suse.com
- Fix building with Qt 5.9 - gh#keepassxreboot/keepassxc#528
  * keepassxc-qt5.9.patch
* Mon Apr 17 2017 mpluskal@suse.com
- Update to version 2.1.4:
  * Bumped KeePassHTTP version to 1.8.4.2
  * KeePassHTTP confirmation window comes to foreground [#466]
* Fri Apr  7 2017 mpluskal@suse.com
- Fetch gpg key from web
* Fri Mar  3 2017 mpluskal@suse.com
- Update to version 2.1.3:
  * Fix possible overflow in zxcvbn library [#363]
  * Revert HiDPI setting to avoid problems on laptop screens [#332]
  * Set file meta properties in Windows executable [#330]
  * Suppress error message when auto-reloading a locked database [#345]
  * Improve usability of question dialog when database is already locked by a different instance [#346]
  * Fix compiler warnings in QHttp library [#351]
  * Use unified toolbar on Mac OS X [#361]
  * Fix an issue on X11 where the main window would be raised instead of closed on Alt+F4 [#362]
* Thu Mar  2 2017 mpluskal@suse.com
- Update dependencies (fixes boo#1027653)
* Sat Feb 25 2017 mpluskal@suse.com
- Update to version 2.1.2:
  * Ask for save location when creating a new database [#302]
  * Remove Libmicrohttpd dependency to clean up the code and ensure better OS X compatibility [#317, #265]
  * Prevent Qt from degrading Wifi network performance on certain platforms [#318]
  * Visually refine user interface on OS X and other platforms [#299]
  * Remove unusable tray icon setting on OS X [#293]
  * Fix compositing glitches on Ubuntu and prevent flashing when minimizing to the tray at startup [#307]
  * Fix AppImage tray icon on Ubuntu [#277, #273]
  * Fix global menu disappearing after restoring KeePassXC from the tray on Ubuntu [#276]
  * Fix result order in entry search [#320]
  * Enable HiDPI scaling on supported platforms [#315]
  * Remove empty directories from installation target [#282]
* Tue Feb 21 2017 jengelh@inai.de
- Remove filler words from description
* Thu Feb 16 2017 mpluskal@suse.com
- Initial package for version 2.1.1 (boo#1024998):
  * based on package for keepassx
